@@ -1,2 +1,2 @@
 from .flat_json import Schema, Field, FlatJson
-from .schema import infer_schema
+from .schema import infer_schema, merge_schema
